==> halloy-2025.4.tar.gz: halloy-2025.4/data/src/config/buffer/channel.rs <==
use serde::Deserialize;

use crate::buffer::Color;
use crate::channel::Position;

use super::NicknameClickAction;

#[derive(Debug, Clone, Default, Deserialize)]
pub struct Channel {
    #[serde(default)]
    pub nicklist: Nicklist,
    #[serde(default)]
    pub topic: Topic,
    #[serde(default)]
    pub message: Message,
}

#[derive(Debug, Clone, Default, Deserialize)]
pub struct Message {
    #[serde(default)]
    pub nickname_color: Color,
}

#[derive(Debug, Clone, Deserialize)]
pub struct Nicklist {
    #[serde(default = "default_bool_true")]
    pub enabled: bool,
    #[serde(default)]
    pub position: Position,
    #[serde(default)]
    pub color: Color,
    #[serde(default)]
    pub width: Option<f32>,
    #[serde(default)]
    pub alignment: Alignment,
    #[serde(default = "default_bool_true")]
    pub show_access_levels: bool,
    #[serde(default)]
    pub click: NicknameClickAction,
}

impl Default for Nicklist {
    fn default() -> Self {
        Self {
            enabled: default_bool_true(),
            position: Default::default(),
            color: Default::default(),
            width: Default::default(),
            alignment: Default::default(),
            show_access_levels: default_bool_true(),
            click: Default::default(),
        }
    }
}

#[derive(Debug, Clone, Copy, PartialEq, Eq, Default, Deserialize)]
#[serde(rename_all = "kebab-case")]
pub enum Alignment {
    #[default]
    Left,
    Right,
}

#[derive(Debug, Clone, Copy, Deserialize)]
pub struct Topic {
    #[serde(default)]
    pub enabled: bool,
    #[serde(default = "default_topic_banner_max_lines")]
    pub max_lines: u16,
}

impl Default for Topic {
    fn default() -> Self {
        Self {
            enabled: false,
            max_lines: default_topic_banner_max_lines(),
        }
    }
}

fn default_topic_banner_max_lines() -> u16 {
    2
}

fn default_bool_true() -> bool {
    true
}

==> halloy-2025.9.tar.gz: halloy-2025.9/data/src/config/buffer/channel.rs <==
use serde::Deserialize;

use super::NicknameClickAction;
use crate::buffer::Color;
use crate::channel::Position;
use crate::config::buffer::Away;

#[derive(Debug, Clone, Default, Deserialize)]
#[serde(default)]
pub struct Channel {
    pub nicklist: Nicklist,
    pub topic: Topic,
    pub message: Message,
}

#[derive(Debug, Clone, Default, Deserialize)]
#[serde(default)]
pub struct Message {
    pub nickname_color: Color,
}

#[derive(Debug, Clone, Deserialize)]
#[serde(default)]
pub struct Nicklist {
    pub away: Away,
    pub enabled: bool,
    pub position: Position,
    pub color: Color,
    pub width: Option<f32>,
    pub alignment: Alignment,
    pub show_access_levels: bool,
    pub click: NicknameClickAction,
}

impl Default for Nicklist {
    fn default() -> Self {
        Self {
            away: Away::default(),
            enabled: true,
            position: Position::default(),
            color: Color::default(),
            width: None,
            alignment: Alignment::default(),
            show_access_levels: true,
            click: NicknameClickAction::default(),
        }
    }
}

#[derive(Debug, Clone, Copy, PartialEq, Eq, Default, Deserialize)]
#[serde(rename_all = "kebab-case")]
pub enum Alignment {
    #[default]
    Left,
    Right,
}

#[derive(Debug, Clone, Copy, Deserialize)]
#[serde(default)]
pub struct Topic {
    pub enabled: bool,
    pub max_lines: u16,
}

impl Default for Topic {
    fn default() -> Self {
        Self {
            enabled: false,
            max_lines: 2,
        }
    }
}
